@@ -14,7 +14,7 @@ use File::chmod qw(chmod);
 #######################
 # VERSION
 #######################
-our $VERSION = '1.0.2';
+our $VERSION = '1.0.3';
 
 #######################
 # EXPORT
@@ -135,8 +135,12 @@ sub chmod_recursive {
                                   )
                                 {
                                     push @updated, $path;
-                                    warn
-                                      "chmod_recursive: $path -> $mode->{match_files}->{$match_re}\n"
+                                    warn "chmod_recursive: $path -> "
+                                      . (
+                                        sprintf "%#o",
+                                        $mode->{match_files}->{$match_re}
+                                      )
+                                      . "\n"
                                       if $verbose;
                                 } ## end if ( chmod( $mode->{match_files...}))
                             } ## end foreach my $match_re ( keys...)
@@ -155,8 +159,12 @@ sub chmod_recursive {
                                   )
                                 {
                                     push @updated, $path;
-                                    warn
-                                      "chmod_recursive: $path -> $mode->{match}->{$match_re}\n"
+                                    warn "chmod_recursive: $path -> "
+                                      . (
+                                        sprintf "%#o",
+                                        $mode->{match}->{$match_re}
+                                      )
+                                      . "\n"
                                       if $verbose;
                                 } ## end if ( chmod( $mode->{match...}))
                             } ## end foreach my $match_re ( keys...)
@@ -175,8 +183,8 @@ sub chmod_recursive {
                               )
                             {
                                 push @updated, $path;
-                                warn
-                                  "chmod_recursive: $path -> $mode->{files}\n"
+                                warn "chmod_recursive: $path -> "
+                                  . ( sprintf "%#o", $mode->{files} ) . "\n"
                                   if $verbose;
                             } ## end if ( ( not $file_isa_match...))
                         } ## end if ( -f $path )
@@ -201,8 +209,12 @@ sub chmod_recursive {
                                   )
                                 {
                                     push @updated, $path;
-                                    warn
-                                      "chmod_recursive: $path -> $mode->{match_dirs}->{$match_re}\n"
+                                    warn "chmod_recursive: $path -> "
+                                      . (
+                                        sprintf "%#o",
+                                        $mode->{match_dirs}->{$match_re}
+                                      )
+                                      . "\n"
                                       if $verbose;
                                 } ## end if ( chmod( $mode->{match_dirs...}))
                             } ## end foreach my $match_re ( keys...)
@@ -221,8 +233,12 @@ sub chmod_recursive {
                                   )
                                 {
                                     push @updated, $path;
-                                    warn
-                                      "chmod_recursive: $path -> $mode->{match}->{$match_re}\n"
+                                    warn "chmod_recursive: $path -> "
+                                      . (
+                                        sprintf "%#o",
+                                        $mode->{match}->{$match_re}
+                                      )
+                                      . "\n"
                                       if $verbose;
                                 } ## end if ( chmod( $mode->{match...}))
                             } ## end foreach my $match_re ( keys...)
@@ -241,8 +257,8 @@ sub chmod_recursive {
                               )
                             {
                                 push @updated, $path;
-                                warn
-                                  "chmod_recursive: $path -> $mode->{dirs}\n"
+                                warn "chmod_recursive: $path -> "
+                                  . ( sprintf "%#o", $mode->{dirs} ) . "\n"
                                   if $verbose;
                             } ## end if ( ( not $dir_isa_match...))
                         } ## end elsif ( -d $path )
@@ -377,7 +393,7 @@ Mithun Ayachit  C<< <mithun@cpan.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2014, Mithun Ayachit C<< <mithun@cpan.org> >>. All rights
+Copyright (c) 2015, Mithun Ayachit C<< <mithun@cpan.org> >>. All rights
 reserved.
 
 This module is free software; you can redistribute it and/or modify it
